@@ -11,7 +11,7 @@ shopt -s nullglob
 TMP=`mktemp -t $(basename -s .sh $0)-XXXXXXX`
 trap " /bin/rm -fr $TMP " INT QUIT EXIT HUP KILL ALRM
 
-aws sts get-caller-identity
+aws sts get-caller-identity --output json | jq -Mr .Arn
 
 aws batch describe-compute-environments --output json | \
     jq -Mr ".computeEnvironments[] | select(.tags.creator==\"$USER\") | [ .tags.results, .tags.created ] | @tsv" > $TMP
